@@ -13,8 +13,10 @@
         data <- ordiGetData(match.call(), environment(formula))
     }
     formula <- formula(terms(formula, data = data))
-    X <- formula[[2]]
-    X <- eval(X, environment(formula))
+    ## The following line was eval'ed in environment(formula), but
+    ## that made update() fail. Rethink the line if capscale() fails
+    ## mysteriously at this point.
+    X <- eval(formula[[2]]) #, environment(formula))
     if (!inherits(X, "dist")) {
         comm <- X
         dfun <- match.fun(dfun)
@@ -93,18 +95,18 @@
             colnames(sol$CCA$wa) <- colnames(sol$CCA$v) <-
                 paste("CAP", 1:ncol(sol$CCA$u), sep = "")
     }
-    if (!is.null(sol$CA)) {
+    if (!is.null(sol$CA) && sol$CA$rank > 0) {
         colnames(sol$CA$u) <- names(sol$CA$eig) <- colnames(sol$CA$v) <-
             paste("MDS", 1:ncol(sol$CA$u), sep = "")
-        ## update for negative eigenvalues
-        poseig <- length(sol$CA$eig)
-        if (any(X$eig < 0)) {
-            negax <- X$eig[X$eig < 0]
-            sol$CA$imaginary.chi <- sum(negax)
-            sol$tot.chi <- sol$tot.chi + sol$CA$imaginary.chi
-            sol$CA$imaginary.rank <- length(negax)
-            sol$CA$imaginary.u.eig <- X$negaxes
-        }
+    }
+    ## update for negative eigenvalues
+    poseig <- length(sol$CA$eig)
+    if (any(X$eig < 0)) {
+        negax <- X$eig[X$eig < 0]
+        sol$CA$imaginary.chi <- sum(negax)
+        sol$tot.chi <- sol$tot.chi + sol$CA$imaginary.chi
+        sol$CA$imaginary.rank <- length(negax)
+        sol$CA$imaginary.u.eig <- X$negaxes
     }
     if (!is.null(comm)) {
         comm <- scale(comm, center = TRUE, scale = FALSE)
@@ -123,11 +125,18 @@
                                "/")
             comm <- qr.resid(sol$CCA$QR, comm)
         }
-        if (!is.null(sol$CA)) {
+        if (!is.null(sol$CA) && sol$CA$rank > 0) {
             sol$CA$v.eig <- t(comm) %*% sol$CA$u/sqrt(k)
             sol$CA$v <- sweep(sol$CA$v.eig, 2, sqrt(sol$CA$eig[1:poseig]), 
                               "/")
         }
+    } else {
+        ## input data were dissimilarities, and no 'comm' defined:
+        ## species scores make no sense and are made NA
+        sol$CA$v.eig[] <- sol$CA$v[] <- NA
+        if (!is.null(sol$CCA))
+            sol$CCA$v.eig[] <- sol$CCA$v[] <- NA
+        sol$colsum <- NA
     }
     if (!is.null(sol$CCA)) 
         sol$CCA$centroids <- centroids.cca(sol$CCA$wa, d$modelframe)
