@@ -1,8 +1,8 @@
 "plot.rad" <-
-    function(x, xlab="Rank", ylab="Abundance",  ...)
+    function(x, xlab="Rank", ylab="Abundance", log = "y", ...)
 {
     rnk <- seq(along=x)
-    plot(rnk, x, log="y", xlab=xlab, ylab=ylab, ...)
+    plot(rnk, x, log=log, xlab=xlab, ylab=ylab, ...)
     out <- list(species = cbind(rnk, x))
     class(out) <- "ordiplot"
     invisible(out)
